@@ -343,7 +343,7 @@ def get_gem( cc, capa ):
 
         print(f"I...  gain             {ga:4d};  range({ming:4d},{maxg:5d}) def: {gad} {ga10:.5f}")
 
-
+        # aea - expoauto;  exposure; gain;  gamma
     return aea,aex,aga,agm
 
 
@@ -357,9 +357,9 @@ def set_gem(cc, gain=None, expo=None, mmaga=None):
 
     capa = cc.get_capbilities()
     aea,aex,aga,agm = get_gem(cc, capa)
-    if aex!=None: ex,exd,mine,maxe,ex10 = aex
-    if agm!=None: gm,gmd,minm,maxm,gm10 = agm
-    if aga!=None: ga,gad,ming,maxg,ga10 = aga
+    if aex!=None: ex,exd,mine,maxe,ex10 = aex  #
+    if agm!=None: gm,gmd,minm,maxm,gm10 = agm  #  gamma
+    if aga!=None: ga,gad,ming,maxg,ga10 = aga  # gain
 
 
 
@@ -419,14 +419,17 @@ def set_gem(cc, gain=None, expo=None, mmaga=None):
     if not gain is None:
         if gain == "def":
             if "gain" in capa:
+                print("Q... messing with default gain")
+                print("Q... messing with default gain")
                 cc.setdef_gain()
         elif gain !=-1:
             if "gain" in capa:
-                ga = cc.get_gain()
-                ming = cc.getmin_gain()
-                maxg = cc.getmax_gain()
-                if (ga>maxg) or (ga<ming):
-                    ga = ming
+                #ga,gad,ming,maxg,ga10
+                #ming = cc.getmin_gain()
+                #maxg = cc.getmax_gain()
+                #ga = cc.get_gain()
+                #if (ga>maxg) or (ga<ming):
+                #    ga = ming
                 print(f"i... current gain {ga}   range {ming}, {maxg}")
 
                 ga = int( gain * (maxg-ming)+ming)
