@@ -380,6 +380,16 @@ def cross():
         if request.form.get('expo') == 'EXPO':
             mmwrite(f"expo_setdef True" )
 
+        # FOR THE MOEMNT - HIDDEN CAPABILITY
+        if request.form.get('exposet') == 'EXPOSET':
+            expovalue = request.form.get('expovalue')
+            mmwrite(f"expovalue {expovalue}" )
+        # FOR THE MOEMNT - HIDDEN CAPABILITY
+        if request.form.get('gainset') == 'GAINSET':
+            gainvalue = request.form.get('gainvalue')
+            mmwrite(f"gainvalue {gainvalue}" )
+
+
         if request.form.get('timelaps') == 'TIMELAPS':
             timelaps = request.form.get('timelaps_input')
             try:
@@ -567,6 +577,29 @@ def index30():
 
 
 #('index.html')
+@app.route('/foreground.jpg')
+@auth.login_required
+def foregroundjpg():
+    global  save_bg, frame_bg, frame_bg2, save_fg, frame_fg, frame_fg2, frame_mask, frame_mask_inv #, BGFILE
+
+    if os.path.exists( FGFILE):
+        blank = cv2.imread( FGFILE )
+        frame_fg = blank.copy() # propagate to the system
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("OLD FOREGROUND IMAGE FOUND",r, frame_fg.shape)
+    else:
+        blank = np.zeros((480,640,3), np.uint8)
+        frame_fg = blank.copy() # propagate to the system
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("NO FOREGROUND - black image",r)
+
+    # send direct JPG
+    # return Response( jpg.tobytes() , direct_passthrough= True)
+    # rather than <img />
+    return Response( jpg.tobytes() + b'\r\n\r\n', mimetype='multipart/x-mixed-replace; boundary=frame')
+    # <img>
+    return Response(b'--frame\r\n' b'Content-Type: image/jpeg\r\n\r\n' + jpg.tobytes() + b'\r\n\r\n', mimetype='multipart/x-mixed-replace; boundary=frame')
+
 
 @app.route('/foreground')
 @auth.login_required
@@ -594,6 +627,31 @@ def foreground():
 
 
 
+@app.route('/background.jpg')
+@auth.login_required
+def backgroundjpg():
+    global  save_bg, frame_bg, frame_bg2, save_fg, frame_fg, frame_fg2, frame_mask, frame_mask_inv #, BGFILE
+
+    if os.path.exists( BGFILE):
+        blank = cv2.imread( BGFILE )
+        frame_bg = blank.copy() # propagate to the system
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("OLD BACKGROUND IMAGE FOUND",r, frame_bg.shape)
+    else:
+        blank = np.zeros((480,640,3), np.uint8)
+        frame_bg = blank.copy() # propagate to the system
+        r, jpg = cv2.imencode('.jpg', blank)
+        print("NO BACKGROUND - black image",r)
+
+    # send direct JPG
+    #return Response( jpg.tobytes() , direct_passthrough= True)
+    # rather than <img />
+    # jpg direct?
+    return Response( jpg.tobytes() + b'\r\n\r\n', mimetype='multipart/x-mixed-replace; boundary=frame')
+    # with <img>
+    return Response(b'--frame\r\n' b'Content-Type: image/jpeg\r\n\r\n' + jpg.tobytes() + b'\r\n\r\n', mimetype='multipart/x-mixed-replace; boundary=frame')
+
+
 @app.route('/background')
 @auth.login_required
 def background():
